@@ -1,4 +1,5 @@
 #include <Rcpp.h>
+#include "shared.h"
 
 using std::pow;
 using std::sqrt;
@@ -171,7 +172,7 @@ NumericVector cpp_rkumar(
   NumericVector x(n);
 
   for (int i = 0; i < n; i++) {
-    u = R::runif(0.0, 1.0);
+    u = rng_unif();
     x[i] = invcdf_kumar(u, a[i % na], b[i % nb]);
   }
 
