@@ -8,6 +8,7 @@ test_that("Testing PDFs & PMFs against infinite values", {
   expect_true(!is.nan(dbhatt(Inf)) && is.finite(dbhatt(Inf)))
   expect_true(!is.nan(dfatigue(Inf, 1)) && is.finite(dfatigue(Inf, 1)))
   expect_true(!is.nan(dcat(Inf, c(0.5, 0.5))) && is.finite(dcat(Inf, c(0.5, 0.5))))
+  expect_true(!is.nan(ddlaplace(Inf, 0.5)) && is.finite(ddlaplace(Inf, 0.5)))
   expect_true(!is.nan(ddnorm(Inf)) && is.finite(ddnorm(Inf)))
   expect_true(!is.nan(ddweibull(Inf, 0.5, 1)) && is.finite(ddweibull(Inf, 0.5, 1)))  
   expect_true(!is.nan(dfrechet(Inf)) && is.finite(dfrechet(Inf)))
@@ -50,6 +51,7 @@ test_that("Testing CDFs against infinite values", {
   expect_true(!is.nan(pbhatt(Inf)) && is.finite(pbhatt(Inf)))
   expect_true(!is.nan(pfatigue(Inf, 1)) && is.finite(pfatigue(Inf, 1)))
   expect_true(!is.nan(pcat(Inf, c(0.5, 0.5))) && is.finite(pcat(Inf, c(0.5, 0.5))))
+  expect_true(!is.nan(pdlaplace(Inf, 0.5)) && is.finite(pdlaplace(Inf, 0.5)))
   expect_true(!is.nan(pdnorm(Inf)) && is.finite(pdnorm(Inf)))
   expect_true(!is.nan(pdweibull(Inf, 0.5, 1)) && is.finite(pdweibull(Inf, 0.5, 1)))  
   expect_true(!is.nan(pfrechet(Inf)) && is.finite(pfrechet(Inf)))
@@ -94,6 +96,7 @@ test_that("Testing PDFs & PMFs against negatively infinite values", {
   expect_true(!is.nan(dbhatt(-Inf)) && is.finite(dbhatt(-Inf)))
   expect_true(!is.nan(dfatigue(-Inf, 1)) && is.finite(dfatigue(-Inf, 1)))
   expect_true(!is.nan(dcat(-Inf, c(0.5, 0.5))) && is.finite(dcat(-Inf, c(0.5, 0.5))))
+  expect_true(!is.nan(ddlaplace(-Inf, 0.5)) && is.finite(ddlaplace(-Inf, 0.5)))
   expect_true(!is.nan(ddnorm(-Inf)) && is.finite(ddnorm(-Inf)))
   expect_true(!is.nan(ddweibull(-Inf, 0.5, 1)) && is.finite(ddweibull(-Inf, 0.5, 1)))  
   expect_true(!is.nan(dfrechet(-Inf)) && is.finite(dfrechet(-Inf)))
@@ -136,6 +139,7 @@ test_that("Testing CDFs against negatively infinite values", {
   expect_true(!is.nan(pbhatt(-Inf)) && is.finite(pbhatt(-Inf)))
   expect_true(!is.nan(pfatigue(-Inf, 1)) && is.finite(pfatigue(-Inf, 1)))
   expect_true(!is.nan(pcat(-Inf, c(0.5, 0.5))) && is.finite(pcat(-Inf, c(0.5, 0.5))))
+  expect_true(!is.nan(pdlaplace(-Inf, 0.5)) && is.finite(pdlaplace(-Inf, 0.5)))
   expect_true(!is.nan(pdnorm(-Inf)) && is.finite(pdnorm(-Inf)))
   expect_true(!is.nan(pdweibull(-Inf, 0.5, 1)) && is.finite(pdweibull(-Inf, 0.5, 1)))  
   expect_true(!is.nan(pfrechet(-Inf)) && is.finite(pfrechet(-Inf)))
